@@ -22,5 +22,5 @@ echo SUCCESS
 echo
 echo git commit -m $version
 echo git tag -a -m $version $version
-echo git push --tags
+echo git push --follow-tags
 echo python -m twine upload -u __token__ dist/*
