@@ -7,12 +7,13 @@ from django.contrib.auth.admin import UserAdmin
 from django.db import models
 from django.db.models.fields.reverse_related import ForeignObjectRel, OneToOneRel
 from django.forms.models import _get_foreign_key
+from django.urls import reverse
+from django.utils.html import format_html
+from django.utils.text import slugify
 
 from .common import debug_log, settings
-from .helpers import AdminMixin, AnnotationDescriptor
+from .helpers import AdminMixin, AnnotationDescriptor, attributes
 from .orm_fields import (
-    OPEN_IN_ADMIN,
-    OrmAdminField,
     OrmAnnotatedField,
     OrmCalculatedField,
     OrmConcreteField,
@@ -52,6 +53,8 @@ except ImportError:  # pragma: django < 3.1
         JSONField = None.__class__
 
 
+OPEN_IN_ADMIN = "admin"
+
 _STRING_FIELDS = (
     models.CharField,
     models.TextField,
@@ -75,6 +78,17 @@ _FIELD_TYPE_MAP = {
 }
 
 
+@attributes(short_description=OPEN_IN_ADMIN)
+def open_in_admin(obj):
+    if obj is None:  # pragma: no cover
+        return None
+
+    model_name = get_model_name(obj.__class__, "_")
+    url_name = f"admin:{model_name}_change".lower()
+    url = reverse(url_name, args=[obj.pk])
+    return format_html('<a href="{}">{}</a>', url, obj)
+
+
 def admin_get_queryset(admin, request, fields=()):
     request.data_browser = {"calculated_fields": set(fields), "fields": set(fields)}
     return admin.get_queryset(request)
@@ -121,7 +135,7 @@ def _get_all_admin_fields(request):
             all_admin_fields[model].update(from_fieldsets(model_admin, True))
             all_admin_fields[model].update(model_admin.get_list_display(request))
             all_admin_fields[model].update(getattr(model_admin, "ddb_extra_fields", []))
-            all_admin_fields[model].add(OPEN_IN_ADMIN)
+            all_admin_fields[model].add(open_in_admin)
             if isinstance(model_admin, AdminMixin):
                 all_admin_fields[model].update(model_admin._ddb_annotations())
             hidden_fields[model].update(getattr(model_admin, "ddb_hide_fields", []))
@@ -162,46 +176,56 @@ def _get_all_admin_fields(request):
 
 
 def _get_calculated_field(request, field_name, model_name, model, admin, model_fields):
-    field_func = getattr(admin, field_name, None)
+    if isinstance(field_name, str):
+        field_func = getattr(admin, field_name, None)
+    else:
+        field_func = field_name
+        field_name = getattr(
+            field_func, "short_description", slugify(str(field_func.__name__))
+        )
+
     if isinstance(field_func, AnnotationDescriptor):
-        admin_order_field = field_func.admin_order_field
         qs = admin_get_queryset(admin, request, [field_name])
 
-        annotation = qs.query.annotations.get(admin_order_field)
+        annotation = qs.query.annotations.get(field_name)
         if not annotation:  # pragma: no cover
             raise Exception(
-                f"Can't find annotation '{admin_order_field}' for {admin}.{field_name}"
+                f"Can't find annotation '{field_name}' for {admin}.{field_name}"
             )
 
         field_type = getattr(annotation, "output_field", None)
         if not field_type:  # pragma: no cover
             raise Exception(
-                f"Annotation '{admin_order_field}' for {admin}.{field_name} doesn't specify 'output_field'"
+                f"Annotation '{field_name}' for {admin}.{field_name} doesn't specify 'output_field'"
             )
 
-        type_, choices = _get_field_type(model, admin_order_field, field_type)
-        if type_:  # pragma: no branch
-            return OrmAnnotatedField(
-                model_name=model_name,
-                name=field_name,
-                pretty_name=field_name,
-                type_=type_,
-                field_type=field_type,
-                admin=admin,
-                admin_order_field=admin_order_field,
-                choices=choices,
-            )
+        type_, choices = _get_field_type(model, field_name, field_type)
+        return OrmAnnotatedField(
+            model_name=model_name,
+            name=field_name,
+            pretty_name=field_name,
+            type_=type_,
+            field_type=field_type,
+            admin=admin,
+            choices=choices,
+        )
     else:
-        if not getattr(getattr(admin, field_name, None), "ddb_hide", False):
-            return OrmCalculatedField(
-                model_name=model_name,
-                name=field_name,
-                pretty_name=field_name,
-                admin=admin,
-            )
-        else:
+        if getattr(field_func, "ddb_hide", False):
             return None
 
+        if field_func is None:
+
+            def field_func(obj):
+                value = getattr(obj, field_name)
+                return value() if callable(value) else value
+
+        return OrmCalculatedField(
+            model_name=model_name,
+            name=field_name,
+            pretty_name=field_name,
+            func=field_func,
+        )
+
 
 def _fmt_choices(choices):
     return [(value, str(label)) for value, label in choices]
@@ -266,9 +290,7 @@ def _get_fields_for_model(request, model, admin, admin_fields):
 
     for field_name in admin_fields[model]:
         field = model_fields.get(field_name)
-        if field_name == OPEN_IN_ADMIN:
-            fields[OPEN_IN_ADMIN] = OrmAdminField(model_name=model_name)
-        elif isinstance(field, (models.ForeignKey, OneToOneRel)):
+        if isinstance(field, (models.ForeignKey, OneToOneRel)):
             if field.related_model in admin_fields:
                 fields[field_name] = OrmFkField(
                     model_name=model_name,
@@ -290,7 +312,7 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                 request, field_name, model_name, model, admin, model_fields
             )
             if orm_field:
-                fields[field_name] = orm_field
+                fields[orm_field.name] = orm_field
         else:
             field_type, choices = _get_field_type(model, field_name, field)
 
