@@ -17,7 +17,6 @@ from django.db.models import (
     functions,
 )
 from django.db.models.functions import Cast
-from django.urls import reverse
 from django.utils.html import format_html
 
 from .types import (
@@ -36,8 +35,6 @@ from .types import (
     YearType,
 )
 
-OPEN_IN_ADMIN = "admin"
-
 _TYPE_AGGREGATES = defaultdict(
     lambda: [("count", NumberType)],
     {
@@ -268,7 +265,6 @@ class OrmBaseField:
     concrete: bool = False
     rel_name: str = None
     can_pivot: bool = False
-    admin: object = None
     choices: Sequence[Tuple[str, str]] = ()
 
     def __post_init__(self):
@@ -278,6 +274,9 @@ class OrmBaseField:
             assert self.type_
 
     def format(self, value):
+        if value is None:
+            return None
+
         return self.type_.format(value, self.choices)
 
 
@@ -323,10 +322,14 @@ class OrmConcreteField(OrmBaseField):
 
 
 class OrmCalculatedField(OrmBaseField):
-    def __init__(self, model_name, name, pretty_name, admin):
-        super().__init__(
-            model_name, name, pretty_name, type_=StringType, can_pivot=True, admin=admin
-        )
+    def __init__(self, model_name, name, pretty_name, func):
+        if getattr(func, "boolean", False):
+            type_ = BooleanType
+        else:
+            type_ = HTMLType
+
+        super().__init__(model_name, name, pretty_name, type_=type_, can_pivot=True)
+        self.func = func
 
     def bind(self, previous):
         previous = previous or OrmBoundField.blank()
@@ -344,20 +347,12 @@ class OrmCalculatedField(OrmBaseField):
         if obj is None:
             return None
 
-        if hasattr(self.admin, self.name):
-            # admin callable
-            func = getattr(self.admin, self.name)
-            try:
-                return func(obj)
-            except Exception as e:
-                return str(e)
-        else:
-            # model property or callable
-            try:
-                value = getattr(obj, self.name)
-                return value() if callable(value) else value
-            except Exception as e:
-                return str(e)
+        try:
+            value = self.func(obj)
+        except Exception as e:
+            return str(e)
+
+        return super().format(value)
 
 
 class OrmBoundAnnotatedField(OrmBoundField):
@@ -369,7 +364,7 @@ class OrmBoundAnnotatedField(OrmBoundField):
                 self.queryset_path: Subquery(
                     admin_get_queryset(self.admin, request, [self.name])
                     .filter(pk=OuterRef(s(self.previous.full_path + ["id"])))
-                    .values(self.admin_order_field)[:1],
+                    .values(self.name)[:1],
                     output_field=self.field_type,
                 )
             }
@@ -378,15 +373,7 @@ class OrmBoundAnnotatedField(OrmBoundField):
 
 class OrmAnnotatedField(OrmBaseField):
     def __init__(
-        self,
-        model_name,
-        name,
-        pretty_name,
-        type_,
-        field_type,
-        admin,
-        admin_order_field,
-        choices=None,
+        self, model_name, name, pretty_name, type_, field_type, admin, choices=None
     ):
         super().__init__(
             model_name,
@@ -394,12 +381,11 @@ class OrmAnnotatedField(OrmBaseField):
             pretty_name,
             type_=type_,
             can_pivot=True,
-            admin=admin,
             concrete=True,
             choices=choices or (),
         )
         self.field_type = field_type
-        self.admin_order_field = admin_order_field
+        self.admin = admin
 
     def bind(self, previous):
         previous = previous or OrmBoundField.blank()
@@ -415,34 +401,6 @@ class OrmAnnotatedField(OrmBaseField):
         )
 
 
-class OrmAdminField(OrmBaseField):
-    def __init__(self, model_name):
-        super().__init__(
-            model_name, OPEN_IN_ADMIN, OPEN_IN_ADMIN, type_=HTMLType, can_pivot=True
-        )
-
-    def bind(self, previous):
-        previous = previous or OrmBoundField.blank()
-        full_path = previous.full_path + [self.name]
-        return OrmBoundField(
-            field=self,
-            previous=previous,
-            full_path=full_path,
-            pretty_path=previous.pretty_path + [self.pretty_name],
-            queryset_path=s(previous.full_path + ["id"]),
-            model_name=self.model_name,
-        )
-
-    def format(self, obj):
-        if obj is None:
-            return None
-
-        model_name = get_model_name(obj.__class__, "_")
-        url_name = f"admin:{model_name}_change".lower()
-        url = reverse(url_name, args=[obj.pk])
-        return f'<a href="{url}">{obj}</a>'
-
-
 class OrmFileField(OrmConcreteField):
     def __init__(self, model_name, name, pretty_name, django_field):
         super().__init__(
@@ -453,6 +411,7 @@ class OrmFileField(OrmConcreteField):
     def format(self, value):
         if not value:
             return None
+
         try:
             # some storage backends will hard fail if their underlying storage isn't
             # setup right https://github.com/tolomea/django-data-browser/issues/11
