@@ -62,6 +62,10 @@ class Query {
     else return String(this.config.types[lookup_type].defaultValue);
   }
 
+  _getFieldIndex(field, fields) {
+    return fields.findIndex((f) => f.pathStr === field.pathStr);
+  }
+
   addField(path, prettyPath, sort) {
     const newFields = this.query.fields.filter(
       (f) => f.pathStr !== path.join("__")
@@ -70,7 +74,6 @@ class Query {
       .map((f) => f.priority)
       .filter((f) => f !== null);
     const newPriority = priorities.length ? Math.max(...priorities) + 1 : 0;
-    console.log("a", priorities, newPriority);
     newFields.push({
       path: path,
       pathStr: path.join("__"),
@@ -83,15 +86,44 @@ class Query {
   }
 
   removeField(field) {
-    this.setQuery({
-      fields: this.query.fields.filter((f) => f.pathStr !== field.pathStr),
-    });
+    const modelField = this.getField(field.path);
+    this.setQuery(
+      {
+        fields: this.query.fields.filter((f) => f.pathStr !== field.pathStr),
+      },
+      modelField.canPivot
+    );
+  }
+
+  moveField(field, left) {
+    const modelField = this.getField(field.path);
+
+    // get the fields in their sections
+    const colFields = this.colFields();
+    const rowFields = this.rowFields();
+    const resFields = this.resFields();
+
+    // pick the section our field is in
+    let fields = null;
+    if (field.pivoted) fields = colFields;
+    else if (modelField.canPivot) fields = rowFields;
+    else fields = resFields;
+
+    // work out it's old and new index
+    const index = this._getFieldIndex(field, fields);
+    const newIndex = index + (left ? -1 : 1);
+
+    // if anything changed then update our section and then
+    // rebuild all the fields from the sections
+    if (0 <= newIndex && newIndex < fields.length) {
+      fields.splice(index, 1);
+      fields.splice(newIndex, 0, field);
+      this.setQuery({ fields: rowFields.concat(colFields, resFields) }, false);
+    }
   }
 
   toggleSort(field) {
-    const index = this.query.fields.findIndex(
-      (f) => f.pathStr === field.pathStr
-    );
+    const index = this._getFieldIndex(field, this.query.fields);
     const newSort = { asc: "dsc", dsc: null, null: "asc" }[field.sort];
     let newFields = this.query.fields.slice();
 
@@ -124,9 +156,7 @@ class Query {
   }
 
   togglePivot(field) {
-    const index = this.query.fields.findIndex(
-      (f) => f.pathStr === field.pathStr
-    );
+    const index = this._getFieldIndex(field, this.query.fields);
     let newFields = this.query.fields.slice();
     newFields[index].pivoted = !newFields[index].pivoted;
     this.setQuery({
